Learn R Programming

applicable (version 0.2.1)

applicable-package: applicable: A Compilation of Applicability Domain Methods

Description

logo

A modeling package compiling applicability domain methods in R. It combines different methods to measure the amount of extrapolation new samples can have from the training set. See tools:::Rd_expr_doi("10.4018/IJQSPR.2016010102") for an overview of applicability domains.

Arguments

Author

Maintainer: Marly Gotti marlygotti@gmail.com

Authors:

Other contributors:

  • Posit Software, PBC (ROR) [copyright holder, funder]

See Also